@@ -6,7 +6,7 @@
 
 package Devel::REPL::Plugin::NewlineHack;
 
-use Moose::Role;
+use Devel::REPL::Plugin;
 use namespace::clean -except => [ 'meta' ];
 
 warn <<EOW;
@@ -18,3 +18,11 @@ EOW
 
 1;
 
+__END__
+
+=head1 NAME
+
+Devel::REPL::Plugin::NewlineHack - (deprecated)
+
+=cut
+
